resultSet.DeserializationHandler

|  | ## Cheshire3 Object Model: Class DeserializationHandler

Module resultSet :: Class DeserializationHandler

## Class DeserializationHandler
source code

Object Tree:

    xml.sax.handler.ContentHandler --+
                                     |
                                    DeserializationHandler

Instance Methods

reinit(self, session, set)
startElement(self, name, attrs) Signals the start of an element in non-namespace mode.
endElement(self, name) Signals the end of an element in non-namespace mode.
characters(self, text) Receive notification of character data.
Inherited from `xml.sax.handler.ContentHandler`: `__init__`, `endDocument`, `endElementNS`, `endPrefixMapping`, `ignorableWhitespace`, `processingInstruction`, `setDocumentLocator`, `skippedEntity`, `startDocument`, `startElementNS`, `startPrefixMapping`

Class Variables

items |
item |
set |
session |
currContent |

Method Details

### reinit(self, session, set) | source code

### startElement(self, name, attrs) | source code
Signals the start of an element in non-namespace mode. The name parameter contains the raw XML 1.0 name of the element type as a string and the attrs parameter holds an instance of the Attributes class containing the attributes of the element. Overrides: xml.sax.handler.ContentHandler.startElement (inherited documentation)

### endElement(self, name) | source code
Signals the end of an element in non-namespace mode. The name parameter contains the name of the element type, just as with the startElement event. Overrides: xml.sax.handler.ContentHandler.endElement (inherited documentation)

### characters(self, text) | source code
Receive notification of character data. The Parser will call this method to report each chunk of character data. SAX parsers may return all contiguous character data in a single chunk, or they may split it into several chunks; however, all of the characters in any single event must come from the same external entity so that the Locator provides useful information. Overrides: xml.sax.handler.ContentHandler.characters (inherited documentation)

Class Variable Details

    ### items Value:
        []

    ### item Value:
        None

    ### set Value:
        None

    ### session Value:
        None

    ### currContent Value:
        ''